==> avatax-rest-v2-api-java_2.11-2.17.1.35-sources.jar: net/avalara/avatax/rest/client/models/CycleExpireOptionModel.java <==
package net.avalara.avatax.rest.client.models;

import net.avalara.avatax.rest.client.enums.*;
import net.avalara.avatax.rest.client.serializer.JsonSerializer;

import java.lang.Override;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;

/**
 * Options for expiring a filing calendar.
 */
public class CycleExpireOptionModel {
    private Date transactionalPeriodStart;

    /**
     * Getter for transactionalPeriodStart - The period start date for the customer's first transaction in the jurisdiction being expired.
     */
    public Date getTransactionalPeriodStart() {
        return this.transactionalPeriodStart;
    }

    /**
     * Setter for transactionalPeriodStart - The period start date for the customer's first transaction in the jurisdiction being expired.
     */
    public void setTransactionalPeriodStart(Date transactionalPeriodStart) {
        this.transactionalPeriodStart = transactionalPeriodStart;
    }

    
    private Date transactionalPeriodEnd;

    /**
     * Getter for transactionalPeriodEnd - The period end date for the customer's last transaction in the jurisdiction being expired.
     */
    public Date getTransactionalPeriodEnd() {
        return this.transactionalPeriodEnd;
    }

    /**
     * Setter for transactionalPeriodEnd - The period end date for the customer's last transaction in the jurisdiction being expired.
     */
    public void setTransactionalPeriodEnd(Date transactionalPeriodEnd) {
        this.transactionalPeriodEnd = transactionalPeriodEnd;
    }

    
    private Date filingDueDate;

    /**
     * Getter for filingDueDate - The jurisdiction-assigned due date for the form.
     */
    public Date getFilingDueDate() {
        return this.filingDueDate;
    }

    /**
     * Setter for filingDueDate - The jurisdiction-assigned due date for the form.
     */
    public void setFilingDueDate(Date filingDueDate) {
        this.filingDueDate = filingDueDate;
    }

    
    private String cycleName;

    /**
     * Getter for cycleName - A descriptive name of the cycle and due date of the form.
     */
    public String getCycleName() {
        return this.cycleName;
    }

    /**
     * Setter for cycleName - A descriptive name of the cycle and due date of the form.
     */
    public void setCycleName(String cycleName) {
        this.cycleName = cycleName;
    }

    


    /**
     * Returns a JSON string representation of CycleExpireOptionModel.
     */
    @Override
    public String toString() {
        return JsonSerializer.SerializeObject(this);
    }
}

==> avatax-rest-v2-api-java_2.11-2.17.4.60-sources.jar: net/avalara/avatax/rest/client/models/CycleExpireOptionModel.java <==
package net.avalara.avatax.rest.client.models;

import net.avalara.avatax.rest.client.enums.*;
import net.avalara.avatax.rest.client.serializer.JsonSerializer;

import java.lang.Override;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;

/**
 * Options for expiring a filing calendar.
 */
public class CycleExpireOptionModel {
    private Date transactionalPeriodStart;

    /**
     * Getter for transactionalPeriodStart - Options for expiring a filing calendar.
     */
    public Date getTransactionalPeriodStart() {
        return this.transactionalPeriodStart;
    }

    /**
     * Setter for transactionalPeriodStart - Options for expiring a filing calendar.
     */
    public void setTransactionalPeriodStart(Date transactionalPeriodStart) {
        this.transactionalPeriodStart = transactionalPeriodStart;
    }

    
    private Date transactionalPeriodEnd;

    /**
     * Getter for transactionalPeriodEnd - Options for expiring a filing calendar.
     */
    public Date getTransactionalPeriodEnd() {
        return this.transactionalPeriodEnd;
    }

    /**
     * Setter for transactionalPeriodEnd - Options for expiring a filing calendar.
     */
    public void setTransactionalPeriodEnd(Date transactionalPeriodEnd) {
        this.transactionalPeriodEnd = transactionalPeriodEnd;
    }

    
    private Date filingDueDate;

    /**
     * Getter for filingDueDate - Options for expiring a filing calendar.
     */
    public Date getFilingDueDate() {
        return this.filingDueDate;
    }

    /**
     * Setter for filingDueDate - Options for expiring a filing calendar.
     */
    public void setFilingDueDate(Date filingDueDate) {
        this.filingDueDate = filingDueDate;
    }

    
    private String cycleName;

    /**
     * Getter for cycleName - Options for expiring a filing calendar.
     */
    public String getCycleName() {
        return this.cycleName;
    }

    /**
     * Setter for cycleName - Options for expiring a filing calendar.
     */
    public void setCycleName(String cycleName) {
        this.cycleName = cycleName;
    }

    


    /**
     * Returns a JSON string representation of CycleExpireOptionModel.
     */
    @Override
    public String toString() {
        return JsonSerializer.SerializeObject(this);
    }
}
